<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="1.1" language="nl">
<defaultcodec></defaultcodec>
<context>
    <name>CBoatElementWidget</name>
    <message>
        <source>Sail information</source>
        <translation type="obsolete">Zeil informatie</translation>
    </message>
    <message>
        <location filename="../boatdef-panel.cpp" line="145"/>
        <source>file</source>
        <translation>bestand</translation>
    </message>
    <message>
        <location filename="../boatdef-panel.cpp" line="146"/>
        <source>name</source>
        <translation>naam</translation>
    </message>
    <message>
        <location filename="../boatdef-panel.cpp" line="147"/>
        <source>Reload</source>
        <translation>Opnieuw laden</translation>
    </message>
    <message>
        <location filename="../boatdef-panel.cpp" line="148"/>
        <source>Remove</source>
        <translation>Verwijderen</translation>
    </message>
    <message>
        <location filename="../boatdef-panel.cpp" line="149"/>
        <source>Update</source>
        <translation>Verversen</translation>
    </message>
    <message>
        <location filename="../boatdef-panel.cpp" line="144"/>
        <source>Element information</source>
        <translation>Deel informatie</translation>
    </message>
</context>
<context>
    <name>CFileIO</name>
    <message>
        <source>Open</source>
        <translation type="obsolete">Openen</translation>
    </message>
    <message>
        <source>Save</source>
        <translation type="obsolete">Opslaan</translation>
    </message>
</context>
<context>
    <name>CFileWriter</name>
    <message>
        <location filename="../filewriter.h" line="151"/>
        <source>error</source>
        <translation>fout</translation>
    </message>
    <message>
        <location filename="../filewriter.h" line="151"/>
        <source>There was an error writing to the selected file.</source>
        <translation>Er is een fout opgetreden bij het opslaan van het bestand.</translation>
    </message>
    <message>
        <location filename="../filewriter.h" line="88"/>
        <source>Open</source>
        <translation>Openen</translation>
    </message>
    <message>
        <location filename="../filewriter.h" line="110"/>
        <source>There was an error reading from the selected file.</source>
        <translation>Er is een fout opgetreden bij het lezen van het bestand.</translation>
    </message>
    <message>
        <location filename="../filewriter.h" line="127"/>
        <source>Save</source>
        <translation>Opslaan</translation>
    </message>
</context>
<context>
    <name>CFormBoat</name>
    <message>
        <location filename="../formboat.cpp" line="104"/>
        <source>boat</source>
        <translation>boot</translation>
    </message>
    <message>
        <location filename="../formboat.cpp" line="105"/>
        <source>&amp;Add</source>
        <translation>&amp;Toevoegen</translation>
    </message>
    <message>
        <location filename="../formboat.cpp" line="106"/>
        <source>file</source>
        <translation>bestand</translation>
    </message>
    <message>
        <location filename="../formboat.cpp" line="167"/>
        <source>Open</source>
        <translation>Openen</translation>
    </message>
</context>
<context>
    <name>CFormHull</name>
    <message>
        <location filename="../formhull.cpp" line="57"/>
        <source>hull</source>
        <translation>romp</translation>
    </message>
    <message>
        <location filename="../formhull.cpp" line="58"/>
        <source>&amp;Dimensions</source>
        <translation>&amp;Afmetingen</translation>
    </message>
</context>
<context>
    <name>CFormHullDefBase</name>
    <message>
        <location filename="../formhulldefbase.ui" line="20"/>
        <source>Dialog</source>
        <translation>Dialoog</translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="86"/>
        <source>Deck and bottom</source>
        <translation>Dek en bodem</translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="104"/>
        <source>Planking</source>
        <translation>Panelen</translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="116"/>
        <source>Automatic planking</source>
        <translation>Automatische panelen</translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="167"/>
        <source>lower plank angle</source>
        <translation>Onderste paneel hoek</translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="231"/>
        <source>top plank angle</source>
        <translation>Bovenste paneel hoek</translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="238"/>
        <source>Number of planks</source>
        <translation>Aantal panelen</translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="256"/>
        <source>Bottom</source>
        <translation>Bodem</translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="313"/>
        <source>Bottom sweep angle</source>
        <translation>Bodem hoek</translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="334"/>
        <source>%</source>
        <translation>%</translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="446"/>
        <source>Max Width</source>
        <translation>Max Breedte</translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="655"/>
        <source>Forward shape</source>
        <translation>Boeg vorm</translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="662"/>
        <source>Length</source>
        <translation>Lengte</translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="677"/>
        <source>Forward height </source>
        <translation>Boeg hoogte</translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="684"/>
        <source>Max Width position</source>
        <translation>Max Breedte positie</translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="706"/>
        <source>Stem angle</source>
        <translation>Boeg hoek</translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="713"/>
        <source>Transom angle</source>
        <translation>Spiegel hoek</translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="1752"/>
        <source>Aft height</source>
        <translation>Achtersteven hoogte</translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="735"/>
        <source>Aft width</source>
        <translation>Achtersteven breedte</translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="742"/>
        <source>Aft shape</source>
        <translation>Achtersteven vorm</translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="794"/>
        <source>Hull name</source>
        <translation>Romp naam</translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="804"/>
        <source>Deck</source>
        <translation>Dek</translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="1745"/>
        <source>Forward height</source>
        <translation>Boeg hoogte</translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="1068"/>
        <source>Plank 5</source>
        <translation>Paneel 5</translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="1773"/>
        <source>Chine angle</source>
        <translation>Kim hoek</translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="1766"/>
        <source>Sweep angle</source>
        <translation>Zeeg hoek</translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="1759"/>
        <source>Plank angle</source>
        <translation>Paneel hoek</translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="1211"/>
        <source>Plank 4</source>
        <translation>Paneel 4</translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="1354"/>
        <source>Plank 3</source>
        <translation>Paneel 3</translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="1640"/>
        <source>Plank 2</source>
        <translation>Paneel 2</translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="1497"/>
        <source>Plank 1</source>
        <translation>Paneel 1</translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="925"/>
        <source>Plank 6</source>
        <translation>Paneel 6</translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="53"/>
        <source>Check</source>
        <translation>Controleren</translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="60"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="67"/>
        <source>Cancel</source>
        <translation>Opheffen</translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="1826"/>
        <source>Dimensions are in millimeters and angles in degrees measured from horizontal</source>
        <translation>Afmetingen in millimeters en hoeken in graden t.o.v. horizontaal</translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="913"/>
        <source>Planks</source>
        <translation>Panelen</translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="439"/>
        <source>txt_BBW</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="467"/>
        <source>txt_BfwdHeight</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="488"/>
        <source>txt_BLWL</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="509"/>
        <source>txt_BaftW</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="603"/>
        <source>txt_BaftHeight</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="648"/>
        <source>Dead rise angle</source>
        <translation>Bodem hoek</translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="773"/>
        <source>txt_HullID</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="860"/>
        <source>txt_DaftHeight</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="881"/>
        <source>txt_DfwdHeight</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="895"/>
        <source>Side angle</source>
        <translation>Dolboord hoek</translation>
    </message>
</context>
<context>
    <name>CFormMain</name>
    <message>
        <location filename="../formmain.cpp" line="124"/>
        <source>&amp;New</source>
        <translation>&amp;Nieuw</translation>
    </message>
    <message>
        <location filename="../formmain.cpp" line="129"/>
        <source>&amp;Open</source>
        <translation>&amp;Openen</translation>
    </message>
    <message>
        <location filename="../formmain.cpp" line="131"/>
        <source>&amp;Save</source>
        <translation>Op&amp;slaan</translation>
    </message>
    <message>
        <location filename="../formmain.cpp" line="132"/>
        <source>Save &amp;As</source>
        <translation>Opslaan &amp;Als</translation>
    </message>
    <message>
        <source>to &amp;DXF</source>
        <translation type="obsolete">naar &amp;DXF</translation>
    </message>
    <message>
        <source>to &amp;TXT sail</source>
        <translation type="obsolete">naar &amp;TXT zeil</translation>
    </message>
    <message>
        <source>to &amp;XML sail</source>
        <translation type="obsolete">naar &amp;XML zeil</translation>
    </message>
    <message>
        <location filename="../formmain.cpp" line="134"/>
        <source>&amp;Quit</source>
        <translation>&amp;Afsluiten</translation>
    </message>
    <message>
        <source>&amp;Dimensions</source>
        <translation type="obsolete">&amp;Afmetingen</translation>
    </message>
    <message>
        <source>&amp;Mould</source>
        <translation type="obsolete">&amp;Vorm</translation>
    </message>
    <message>
        <source>&amp;Patches</source>
        <translation type="obsolete">&amp;Hoekverstevigingen</translation>
    </message>
    <message>
        <source>&amp;Rig</source>
        <translation type="obsolete">&amp;Tuigage</translation>
    </message>
    <message>
        <location filename="../formmain.cpp" line="138"/>
        <source>Language</source>
        <translation>Taal</translation>
    </message>
    <message>
        <location filename="../formmain.cpp" line="150"/>
        <source>About &amp;Qt</source>
        <translation>Over &amp;Qt</translation>
    </message>
    <message>
        <location filename="../formmain.cpp" line="151"/>
        <source>About &amp;Sailcut CAD</source>
        <translation>Over &amp;Sailcut CAD</translation>
    </message>
    <message>
        <location filename="../formmain.cpp" line="122"/>
        <source>&amp;File</source>
        <translation>&amp;Bestand</translation>
    </message>
    <message>
        <location filename="../formmain.cpp" line="137"/>
        <source>&amp;View</source>
        <translation>Beel&amp;d</translation>
    </message>
    <message>
        <location filename="../formmain.cpp" line="148"/>
        <source>&amp;Help</source>
        <translation>&amp;Help</translation>
    </message>
    <message>
        <location filename="../formmain.cpp" line="327"/>
        <source>About Sailcut CAD</source>
        <translation>Over Sailcut CAD</translation>
    </message>
    <message>
        <source>error</source>
        <translation type="obsolete">fout</translation>
    </message>
    <message>
        <source>There was an error writing to the selected file</source>
        <translation type="obsolete">Er is een fout opgetreden bij het opslaan van het bestand</translation>
    </message>
    <message>
        <location filename="../formmain.cpp" line="130"/>
        <source>Open &amp;recent</source>
        <translation>Onlangs &amp;geopend</translation>
    </message>
    <message>
        <source>E&amp;xport 3D sail</source>
        <translation type="obsolete">3D zeil e&amp;xporteren</translation>
    </message>
    <message>
        <source>to &amp;Carlson plotter</source>
        <translation type="obsolete">naar &amp;Carlson plotter</translation>
    </message>
    <message>
        <source>Export &amp;development</source>
        <translation type="obsolete">Zeil&amp;banen exporteren</translation>
    </message>
    <message>
        <location filename="../formmain.cpp" line="149"/>
        <source>Sailcut CAD &amp;Handbook</source>
        <translation>Sailcut CAD &amp;Handboek</translation>
    </message>
    <message>
        <source>shaded view</source>
        <translation type="obsolete">3D model</translation>
    </message>
    <message>
        <source>wireframe view</source>
        <translation type="obsolete">draadmodel</translation>
    </message>
    <message>
        <source>development</source>
        <translation type="obsolete">banen</translation>
    </message>
    <message>
        <source>created new sail</source>
        <translation type="obsolete">nieuw zeil gecreëerd</translation>
    </message>
    <message>
        <location filename="../formmain.cpp" line="208"/>
        <source>loaded &apos;%1&apos;</source>
        <translation>&apos;%1&apos; geladen</translation>
    </message>
    <message>
        <location filename="../formmain.cpp" line="213"/>
        <source>error loading &apos;%1&apos;</source>
        <translation>fout bij het laden van &apos;%1&apos;</translation>
    </message>
    <message>
        <location filename="../formmain.cpp" line="487"/>
        <source>wrote &apos;%1&apos;</source>
        <translation>&apos;%1&apos; opgeslagen</translation>
    </message>
    <message>
        <source>There was a data printing error</source>
        <translation type="obsolete">Er is een fout opgetreden bij het printen van de data</translation>
    </message>
    <message>
        <source>There was a development printing error</source>
        <translation type="obsolete">Er is een fout opgetreden bij het printen van banen</translation>
    </message>
    <message>
        <source>There was a drawing printing error</source>
        <translation type="obsolete">Er is een fout opgetreden bij het printen van het tekening</translation>
    </message>
    <message>
        <source>data</source>
        <translation type="obsolete">data</translation>
    </message>
    <message>
        <source>drawing</source>
        <translation type="obsolete">tekening</translation>
    </message>
    <message>
        <source>develop</source>
        <translation type="obsolete">banen</translation>
    </message>
    <message>
        <source>&amp;Print</source>
        <translation type="obsolete">&amp;Print</translation>
    </message>
    <message>
        <source>Sail type</source>
        <translation type="obsolete">Zeil type</translation>
    </message>
    <message>
        <source>Mainsail</source>
        <translation type="obsolete">Grootzeil</translation>
    </message>
    <message>
        <source>Jib</source>
        <translation type="obsolete">Fok</translation>
    </message>
    <message>
        <source>Sail layout</source>
        <translation type="obsolete">Zeilontwerp</translation>
    </message>
    <message>
        <source>Cross Cut</source>
        <translation type="obsolete">Schuin gesneden</translation>
    </message>
    <message>
        <source>Horizontal Cut</source>
        <translation type="obsolete">Horizontaal gesneden</translation>
    </message>
    <message>
        <source>Radial Cut</source>
        <translation type="obsolete">Radiaal gesneden</translation>
    </message>
    <message>
        <source>Twist Foot Cut</source>
        <translation type="obsolete">Gedraaid Onderlijk</translation>
    </message>
    <message>
        <source>Vertical Cut</source>
        <translation type="obsolete">Verticaal gesneden</translation>
    </message>
    <message>
        <source>Mitre Cut</source>
        <translation type="obsolete">Verstek gesneden</translation>
    </message>
    <message>
        <source> sections,   </source>
        <translation type="obsolete"> secties,   </translation>
    </message>
    <message>
        <source> head gores.</source>
        <translation type="obsolete"> top banen.</translation>
    </message>
    <message>
        <source>Rig </source>
        <translation type="obsolete">Tuigage </translation>
    </message>
    <message>
        <source>Boat LOA</source>
        <translation type="obsolete">Scheepslengte LOA</translation>
    </message>
    <message>
        <source>Fore triangle hoist I</source>
        <translation type="obsolete">Voordriehoek hoogte I</translation>
    </message>
    <message>
        <source>Fore triangle base J</source>
        <translation type="obsolete">Voordriehoek basis J</translation>
    </message>
    <message>
        <source>Tack position X</source>
        <translation type="obsolete">Halshoek positie X</translation>
    </message>
    <message>
        <source>Tack height Y</source>
        <translation type="obsolete">Halshoek hoogte Y</translation>
    </message>
    <message>
        <source>Sail dimensions</source>
        <translation type="obsolete">Zeil afmetingen</translation>
    </message>
    <message>
        <source>Luff length</source>
        <translation type="obsolete">Voorlijk lengte</translation>
    </message>
    <message>
        <source>Mast rake</source>
        <translation type="obsolete">Mast helling</translation>
    </message>
    <message>
        <source>Gaff angle wrt luff</source>
        <translation type="obsolete">Gaffel-mast hoek</translation>
    </message>
    <message>
        <source>Gaff length</source>
        <translation type="obsolete">Gaffel lengte</translation>
    </message>
    <message>
        <source>Foot length</source>
        <translation type="obsolete">Onderlijk lengte</translation>
    </message>
    <message>
        <source>Leech length</source>
        <translation type="obsolete">Achterlijk lengte</translation>
    </message>
    <message>
        <source>Shape of edges</source>
        <translation type="obsolete">Vorm van de randen</translation>
    </message>
    <message>
        <source>Luff round</source>
        <translation type="obsolete">Voorlijk ronding</translation>
    </message>
    <message>
        <source>Gaff round</source>
        <translation type="obsolete">Gaffel ronding</translation>
    </message>
    <message>
        <source>Leech round</source>
        <translation type="obsolete">Achterlijk ronding</translation>
    </message>
    <message>
        <source>Foot round</source>
        <translation type="obsolete">Onderlijk ronding</translation>
    </message>
    <message>
        <source>Luff round position</source>
        <translation type="obsolete">Voorlijk ronding positie</translation>
    </message>
    <message>
        <source>Gaff round position</source>
        <translation type="obsolete">Gaffel ronding positie</translation>
    </message>
    <message>
        <source>Leech round position</source>
        <translation type="obsolete">Achterlijk ronding positie</translation>
    </message>
    <message>
        <source>Foot round position</source>
        <translation type="obsolete">Onderlijk ronding positie</translation>
    </message>
    <message>
        <source>Sail settings</source>
        <translation type="obsolete">Zeil instellingen</translation>
    </message>
    <message>
        <source>Twist angle</source>
        <translation type="obsolete">Twist hoek</translation>
    </message>
    <message>
        <source>Sheeting angle</source>
        <translation type="obsolete">Schootlijn hoek</translation>
    </message>
    <message>
        <source>Cloth seams and hems</source>
        <translation type="obsolete">Doek naden en zomen</translation>
    </message>
    <message>
        <source>Cloth width</source>
        <translation type="obsolete">Baan breedte</translation>
    </message>
    <message>
        <source>Seams width</source>
        <translation type="obsolete">Naad breedte</translation>
    </message>
    <message>
        <source>Leech hem width</source>
        <translation type="obsolete">Achterlijk zoom breedte</translation>
    </message>
    <message>
        <source>Other hem width</source>
        <translation type="obsolete">Overige zoom breedte</translation>
    </message>
    <message>
        <source>Sail mould</source>
        <translation type="obsolete">Zeilvorm</translation>
    </message>
    <message>
        <source>Luff factor</source>
        <translation type="obsolete">Voorlijk factor</translation>
    </message>
    <message>
        <source>Depth</source>
        <translation type="obsolete">Diepte</translation>
    </message>
    <message>
        <source>Leech factor</source>
        <translation type="obsolete">Achterlijk factor</translation>
    </message>
    <message>
        <source>Top profile</source>
        <translation type="obsolete">Top profiel</translation>
    </message>
    <message>
        <source>Mid profile at h = </source>
        <translation type="obsolete">Midden profiel bij h = </translation>
    </message>
    <message>
        <source>Bottom profile</source>
        <translation type="obsolete">Onderlijk profiel</translation>
    </message>
    <message>
        <source>Mast/Luff rake</source>
        <translation type="obsolete">Mast/Voorlijk helling</translation>
    </message>
    <message>
        <source> head gores,   </source>
        <translation type="obsolete"> hoofd banen,   </translation>
    </message>
    <message>
        <source> luff gore.</source>
        <translation type="obsolete"> voorlijk baan.</translation>
    </message>
    <message>
        <source>Wing</source>
        <translation type="obsolete">Vleugel</translation>
    </message>
    <message>
        <source> luff gores.</source>
        <translation type="obsolete"> voorlijk banen.</translation>
    </message>
    <message>
        <source>deg</source>
        <translation type="obsolete">gr</translation>
    </message>
    <message>
        <source>to &amp;Hand-plotting format</source>
        <translation type="obsolete">naar &amp;Handmatige plotgegevens</translation>
    </message>
    <message>
        <location filename="../formmain.cpp" line="125"/>
        <source>sail</source>
        <translation>Zeil</translation>
    </message>
    <message>
        <location filename="../formmain.cpp" line="126"/>
        <source>hull</source>
        <translation>romp</translation>
    </message>
    <message>
        <location filename="../formmain.cpp" line="127"/>
        <source>rig</source>
        <translation>tuigage</translation>
    </message>
    <message>
        <location filename="../formmain.cpp" line="128"/>
        <source>boat</source>
        <translation>boot</translation>
    </message>
    <message>
        <location filename="../formmain.cpp" line="141"/>
        <source>&amp;Window</source>
        <translation>&amp;Venster</translation>
    </message>
    <message>
        <location filename="../formmain.cpp" line="142"/>
        <source>&amp;Close</source>
        <translation>&amp;Sluiten</translation>
    </message>
    <message>
        <location filename="../formmain.cpp" line="143"/>
        <source>Close &amp;All</source>
        <translation>&amp;All vensters sluiten</translation>
    </message>
    <message>
        <location filename="../formmain.cpp" line="144"/>
        <source>&amp;Tile</source>
        <translation>Rangschikken</translation>
    </message>
    <message>
        <location filename="../formmain.cpp" line="145"/>
        <source>&amp;Cascade</source>
        <translation>Getrapt</translation>
    </message>
    <message>
        <location filename="../formmain.cpp" line="200"/>
        <source>unknown document type &apos;%1&apos;</source>
        <translation>Onbekend bestandstype &apos;%1&apos;</translation>
    </message>
    <message>
        <location filename="../formmain.cpp" line="444"/>
        <source>Open</source>
        <translation>Openen</translation>
    </message>
</context>
<context>
    <name>CFormMould</name>
    <message>
        <location filename="../formmould.cpp" line="77"/>
        <source>Top profile</source>
        <translation>Top profiel</translation>
    </message>
    <message>
        <location filename="../formmould.cpp" line="78"/>
        <source>Middle profile</source>
        <translation>Midden profiel</translation>
    </message>
    <message>
        <location filename="../formmould.cpp" line="79"/>
        <source>Bottom profile</source>
        <translation>Onderlijk profiel</translation>
    </message>
    <message>
        <location filename="../formmould.cpp" line="42"/>
        <source>Sail mould</source>
        <translation>Zeilvorm</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation type="obsolete">&amp;Help</translation>
    </message>
    <message>
        <location filename="../formmould.cpp" line="56"/>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <location filename="../formmould.cpp" line="60"/>
        <source>&amp;Cancel</source>
        <translation>Op&amp;heffen</translation>
    </message>
    <message>
        <location filename="../formmould.cpp" line="66"/>
        <source>Vertical repartition</source>
        <translation>Verticale verdeling</translation>
    </message>
</context>
<context>
    <name>CFormPanelGroup</name>
    <message>
        <location filename="../formpanelgroup.cpp" line="56"/>
        <source>panels</source>
        <translation>Panelen</translation>
    </message>
</context>
<context>
    <name>CFormPrint</name>
    <message>
        <location filename="../formprint.cpp" line="186"/>
        <source>&amp;Print</source>
        <translation>&amp;Print</translation>
    </message>
    <message>
        <location filename="../formprint.cpp" line="189"/>
        <source>&amp;Cancel</source>
        <translation>Op&amp;heffen</translation>
    </message>
    <message>
        <location filename="../formprint.cpp" line="165"/>
        <source>Scale</source>
        <translation>Schaal</translation>
    </message>
</context>
<context>
    <name>CFormRig</name>
    <message>
        <source>Rig</source>
        <translation type="obsolete">Tuigage</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation type="obsolete">&amp;Nieuw</translation>
    </message>
    <message>
        <source>sail &amp;definition</source>
        <translation type="obsolete">zeil &amp;definitie</translation>
    </message>
    <message>
        <source>3D &amp;sail</source>
        <translation type="obsolete">3D &amp;zeil</translation>
    </message>
    <message>
        <source>&amp;Add sail</source>
        <translation type="obsolete">Zeil &amp;toevoegen</translation>
    </message>
    <message>
        <source>&amp;Open</source>
        <translation type="obsolete">&amp;Openen</translation>
    </message>
    <message>
        <source>Open &amp;recent</source>
        <translation type="obsolete">Onlangs &amp;geopend</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation type="obsolete">Op&amp;slaan</translation>
    </message>
    <message>
        <source>Save &amp;As</source>
        <translation type="obsolete">Opslaan &amp;Als</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="obsolete">&amp;Sluiten</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation type="obsolete">&amp;Bestand</translation>
    </message>
    <message>
        <source>error</source>
        <translation type="obsolete">fout</translation>
    </message>
    <message>
        <source>There was an error writing to the selected file</source>
        <translation type="obsolete">Er is een fout opgetreden bij het opslaan van het bestand</translation>
    </message>
    <message>
        <location filename="../formrig.cpp" line="59"/>
        <source>rig</source>
        <translation>tuigage</translation>
    </message>
    <message>
        <location filename="../formrig.cpp" line="60"/>
        <source>&amp;Dimensions</source>
        <translation>&amp;Afmetingen</translation>
    </message>
</context>
<context>
    <name>CFormRigDefBase</name>
    <message>
        <location filename="../formrigdefbase.ui" line="26"/>
        <source>Rig dimensions</source>
        <translation>Tuigage afmetingen</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="64"/>
        <source>Cancel</source>
        <translation>Opheffen</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="51"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="291"/>
        <source>Spreaders</source>
        <translation>Zalingen</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="338"/>
        <source>= SPNB</source>
        <translation>= SPNB</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="345"/>
        <source>Number of spreaders</source>
        <translation>Aantal zalingen</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="361"/>
        <source>Spreader height</source>
        <translation>Zaling hoogte</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="385"/>
        <source>txt_SPH2</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="407"/>
        <source>txt_SPH1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="429"/>
        <source>txt_SPH3</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="445"/>
        <source>SPH2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="458"/>
        <source>SPH3</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="471"/>
        <source>SPH1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="487"/>
        <source>Spreader length</source>
        <translation>Zaling lengte</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="505"/>
        <source>SPW3</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="518"/>
        <source>txt_SPW3</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="534"/>
        <source>SPW1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="547"/>
        <source>txt_SPW1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="563"/>
        <source>SPW2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="576"/>
        <source>txt_SPW2</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="90"/>
        <source>Shrouds</source>
        <translation>Stagen</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="114"/>
        <source>Cap shroud base width</source>
        <translation>Topstagen basis breedte</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="133"/>
        <source>= CSH</source>
        <translation>= CSH</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="152"/>
        <source>Lower shroud base width </source>
        <translation>Onderstagen basis breedte</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="171"/>
        <source>txt_LSB</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="193"/>
        <source>txt_CSH</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="215"/>
        <source>= CSB</source>
        <translation>= CSB</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="234"/>
        <source>Cap shroud height</source>
        <translation>Topstagen hoogte</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="253"/>
        <source>txt_CSB</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="275"/>
        <source>= LSB</source>
        <translation>= LSB</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1384"/>
        <source>Fore triangle</source>
        <translation>Voordriehoek</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1421"/>
        <source>txt_foreI</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1431"/>
        <source>= I</source>
        <translation>= I</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1450"/>
        <source>txt_foreJ</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1460"/>
        <source>= J</source>
        <translation>= J</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1467"/>
        <source>Fore triangle base</source>
        <translation>Voordriehoek basis</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1474"/>
        <source>Fore triangle hoist</source>
        <translation>Voordriehoek hoogte</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1091"/>
        <source>Mast</source>
        <translation>Mast</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1103"/>
        <source>Mast width</source>
        <translation>Mastdikte</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1110"/>
        <source>= MW</source>
        <translation>= MW</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1123"/>
        <source>txt_MW</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1139"/>
        <source>txt_MC</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1149"/>
        <source>= MC</source>
        <translation>= MC</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1156"/>
        <source>Mast cord</source>
        <translation>Mastbuiging</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1166"/>
        <source>lbl_MRkD</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1176"/>
        <source>= MRkD</source>
        <translation>= MRkD</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1183"/>
        <source>Mast rake angle</source>
        <translation>Mast helling hoek</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1202"/>
        <source>txt_MH</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1212"/>
        <source>txt_MRnd</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1238"/>
        <source>Mast rake</source>
        <translation>Mast helling</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1245"/>
        <source>= MRkM</source>
        <translation>= MRkM</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1264"/>
        <source>txt_MRkM</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1286"/>
        <source>Mast height</source>
        <translation>Mast hoogte</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1293"/>
        <source>= MH</source>
        <translation>= MH</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1300"/>
        <source>= MRnd</source>
        <translation>= MRnd</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1319"/>
        <source>Mast round</source>
        <translation>Mast buiging</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1326"/>
        <source>= MRndPos</source>
        <translation>= MRndPos</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1345"/>
        <source>Mast round position </source>
        <translation>Mast buiging positie</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="604"/>
        <source>Mainsail</source>
        <translation>Grootzeil</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="631"/>
        <source>lbl_MS_LuffRP</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="653"/>
        <source>@ </source>
        <translation>@</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="678"/>
        <source>lbl_MS_LuffR</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="703"/>
        <source>lbl_MS_TackY</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="725"/>
        <source>Y =</source>
        <translation>Y =</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="750"/>
        <source>lbl_MS_TackX</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="766"/>
        <source>X =</source>
        <translation>X =</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="782"/>
        <source>Tack</source>
        <translation>Halshoek</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="820"/>
        <source>lbl_MS_LuffL</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="836"/>
        <source>= MSL</source>
        <translation>= MSL</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="855"/>
        <source>Luff length </source>
        <translation>Voorlijk lengte</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="874"/>
        <source>Luff round</source>
        <translation>Voorlijk ronding</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="896"/>
        <source>lbl_MS_Rake</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="912"/>
        <source>= MSR</source>
        <translation>= MSR</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="931"/>
        <source>Luff rake</source>
        <translation>Voorlijk helling</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="966"/>
        <source>Tack height </source>
        <translation>Halshoek hoogte</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="985"/>
        <source>txt_BAD</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1007"/>
        <source>= BAD</source>
        <translation>= BAD</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1027"/>
        <source>Head height</source>
        <translation>Top hoogte</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1040"/>
        <source>= HAD</source>
        <translation>= HAD</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1059"/>
        <source>txt_HAD</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="38"/>
        <source>Check</source>
        <translation>Controleren</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1544"/>
        <source>All dimensions are in millimeter and angles in degrees</source>
        <translation>All afmetingen in millimeters en hoeken in graden</translation>
    </message>
    <message>
        <source>Rig ID</source>
        <translation type="obsolete">Tuigage ID</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1490"/>
        <source>Description of rig</source>
        <translation>Tuigage beschrijving</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1509"/>
        <source>Rig name</source>
        <translation>Tuigage naam</translation>
    </message>
</context>
<context>
    <name>CFormSail</name>
    <message>
        <location filename="../formsail.cpp" line="74"/>
        <source>sail</source>
        <translation>Zeil</translation>
    </message>
    <message>
        <location filename="../formsail.cpp" line="77"/>
        <source>&amp;Print</source>
        <translation>&amp;Print</translation>
    </message>
    <message>
        <location filename="../formsail.cpp" line="78"/>
        <source>data</source>
        <translation>data</translation>
    </message>
    <message>
        <location filename="../formsail.cpp" line="79"/>
        <source>drawing</source>
        <translation>tekening</translation>
    </message>
    <message>
        <location filename="../formsail.cpp" line="112"/>
        <source>development</source>
        <translation>banen</translation>
    </message>
    <message>
        <location filename="../formsail.cpp" line="83"/>
        <source>E&amp;xport 3D sail</source>
        <translation>3D zeil e&amp;xporteren</translation>
    </message>
    <message>
        <location filename="../formsail.cpp" line="95"/>
        <source>to &amp;DXF</source>
        <translation>naar &amp;DXF</translation>
    </message>
    <message>
        <location filename="../formsail.cpp" line="102"/>
        <source>to &amp;TXT sail</source>
        <translation>naar &amp;TXT zeil</translation>
    </message>
    <message>
        <location filename="../formsail.cpp" line="103"/>
        <source>to &amp;XML sail</source>
        <translation>naar &amp;XML zeil</translation>
    </message>
    <message>
        <location filename="../formsail.cpp" line="93"/>
        <source>Export &amp;development</source>
        <translation>Zeil&amp;banen exporteren</translation>
    </message>
    <message>
        <location filename="../formsail.cpp" line="94"/>
        <source>to &amp;Carlson plotter</source>
        <translation>naar &amp;Carlson plotter</translation>
    </message>
    <message>
        <location filename="../formsail.cpp" line="98"/>
        <source>to &amp;Hand-plotting format</source>
        <translation>naar &amp;Handmatige plotgegevens</translation>
    </message>
    <message>
        <location filename="../formsail.cpp" line="106"/>
        <source>&amp;Dimensions</source>
        <translation>&amp;Afmetingen</translation>
    </message>
    <message>
        <location filename="../formsail.cpp" line="107"/>
        <source>&amp;Mould</source>
        <translation>&amp;Vorm</translation>
    </message>
    <message>
        <location filename="../formsail.cpp" line="108"/>
        <source>&amp;Patches</source>
        <translation>&amp;Hoekverstevigingen</translation>
    </message>
    <message>
        <source>error</source>
        <translation type="obsolete">fout</translation>
    </message>
    <message>
        <source>There was a data printing error</source>
        <translation type="obsolete">Er is een fout opgetreden bij het printen</translation>
    </message>
    <message>
        <source>There was a development printing error</source>
        <translation type="obsolete">Er is een fout opgetreden bij het printen</translation>
    </message>
    <message>
        <source>There was a drawing printing error</source>
        <translation type="obsolete">Er is een fout opgetreden bij het printen</translation>
    </message>
    <message>
        <location filename="../formsail.cpp" line="100"/>
        <source>to &amp;SVG</source>
        <translation>naar &amp;SVG</translation>
    </message>
    <message>
        <location filename="../formsail.cpp" line="96"/>
        <source>to DXF (split)</source>
        <translation>naar DXF (split)</translation>
    </message>
</context>
<context>
    <name>CFormSailDef</name>
    <message>
        <location filename="../formsaildef.cpp" line="1143"/>
        <source>Sail corners coordinates</source>
        <translation>Zeilhoek coördinaten</translation>
    </message>
    <message>
        <location filename="../formsaildef.cpp" line="1144"/>
        <source>tack</source>
        <translation>halshoek</translation>
    </message>
    <message>
        <location filename="../formsaildef.cpp" line="1145"/>
        <source>clew</source>
        <translation>halshoek</translation>
    </message>
    <message>
        <location filename="../formsaildef.cpp" line="1146"/>
        <source>head</source>
        <translation>tophoek</translation>
    </message>
    <message>
        <location filename="../formsaildef.cpp" line="1147"/>
        <source>peak</source>
        <translation>tophoek</translation>
    </message>
    <message>
        <source>IRC width measurements</source>
        <translation type="obsolete">IRC breedtematen</translation>
    </message>
    <message>
        <location filename="../formsaildef.cpp" line="1152"/>
        <source>Sail width measurements </source>
        <translation>Zeilbreedte afmetingen</translation>
    </message>
</context>
<context>
    <name>CFormSailDefBase</name>
    <message>
        <location filename="../formsaildefbase.ui" line="25"/>
        <source>Sail definition</source>
        <translation>Zeil definitie</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="43"/>
        <source>Sail dimensions</source>
        <translation>Zeil afmetingen</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="1681"/>
        <source>mm</source>
        <translation>mm</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="212"/>
        <source>Round position</source>
        <translation>Ronding positie</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="146"/>
        <source>Luff length</source>
        <translation>Voorlijk lengte</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="165"/>
        <source>Foot length</source>
        <translation>Onderlijk lengte</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="191"/>
        <source>Leech length</source>
        <translation>Achterlijk lengte</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="231"/>
        <source>Gaff length</source>
        <translation>Gaffel lengte</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="238"/>
        <source>Leech round</source>
        <translation>Achterlijk ronding</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="354"/>
        <source>Gaff round</source>
        <translation>Gaffel ronding</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="245"/>
        <source>Luff round</source>
        <translation>Voorlijk ronding</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="252"/>
        <source>Foot round</source>
        <translation>Onderlijk ronding</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="1269"/>
        <source>%</source>
        <translation>%</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="1450"/>
        <source>deg</source>
        <translation>gr</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="361"/>
        <source>Gaff angle from luff</source>
        <translation>Gaffel-mast hoek</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="549"/>
        <source>Rig geometry</source>
        <translation>Tuigage geometrie</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="662"/>
        <source>Fore triangle base  J</source>
        <translation>Voordriehoek basis J</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="636"/>
        <source>Tack height</source>
        <translation>Halshoek hoogte</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="824"/>
        <source>Distance tack to stem</source>
        <translation>Afstand halshoek-boeg</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="576"/>
        <source>Main sail</source>
        <translation>Grootzeil</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="602"/>
        <source>Jib</source>
        <translation>Fok</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="629"/>
        <source>Fore triangle hoist  I</source>
        <translation>Voordriehoek hoogte I</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="681"/>
        <source>Boat length LOA</source>
        <translation>Scheepslengte LOA</translation>
    </message>
    <message>
        <source>Mast / Luff rake</source>
        <translation type="obsolete">Mast/Voorlijk helling</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="1460"/>
        <source>Cloth</source>
        <translation>Zeildoek</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="1626"/>
        <source>Seam width</source>
        <translation>Naad breedte</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="1594"/>
        <source>Cloth width</source>
        <translation>Baan breedte</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="905"/>
        <source>Layout</source>
        <translation>Ontwerp</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="1157"/>
        <source>Mitre cut</source>
        <translation>Verstek gesneden</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="929"/>
        <source>Cross cut</source>
        <translation>Schuin gesneden</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="948"/>
        <source>Twist foot</source>
        <translation>Gedraaid Onderlijk</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="1071"/>
        <source>Horizontal cut</source>
        <translation>Horizontaal gesneden</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="967"/>
        <source>Number of sections</source>
        <translation>Aantal secties</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="1027"/>
        <source>Number of radial gores</source>
        <translation>Aantal radiale banen</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="1119"/>
        <source>Radial cut</source>
        <translation>Radiaal gesneden</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="1090"/>
        <source>Vertical cut</source>
        <translation>Vertikaal gesneden</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="1205"/>
        <source>Sail shape</source>
        <translation>Zeilvorm</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="1307"/>
        <source>Top depth</source>
        <translation>Top bolling</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="1329"/>
        <source>Mid depth</source>
        <translation>Midden bolling</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="1351"/>
        <source>Foot depth</source>
        <translation>Onderlijk bolling</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="1411"/>
        <source>Twist angle</source>
        <translation>Twist hoek</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="885"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="869"/>
        <source>Cancel</source>
        <translation>Opheffen</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="1610"/>
        <source>Leech hem</source>
        <translation>Achterlijk zoom</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="1516"/>
        <source>Other hems</source>
        <translation>Overige zomen</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="1433"/>
        <source>Sheeting angle</source>
        <translation>Schoothoek</translation>
    </message>
    <message encoding="UTF-8">
        <source>m²</source>
        <translation type="obsolete">m²</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="451"/>
        <source>Sail area</source>
        <translation>Zeil oppervlak</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="444"/>
        <source>Diagonal</source>
        <translation>Diagonaal</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="898"/>
        <source>Compute</source>
        <translation>Bereken</translation>
    </message>
    <message>
        <source>Sail ID</source>
        <translation type="obsolete">Zeil ID</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="1049"/>
        <source>Number of luff gores</source>
        <translation>Aantal voorlijk banen</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="583"/>
        <source>Dihedral angle</source>
        <translation>Tweevlakshoek</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="615"/>
        <source>Wing</source>
        <translation>Vleugel</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="496"/>
        <source>Sail identifier</source>
        <translation>Zeil ID</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="474"/>
        <source>m2</source>
        <translation>m2</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="530"/>
        <source>Sail name</source>
        <translation>Zeil naam</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="643"/>
        <source>Luff rake</source>
        <translation>Voorlijk helling</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="1176"/>
        <source>Mitre cut 2</source>
        <translation>Verstek 2 gesneden</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="1532"/>
        <source>Foot hem</source>
        <translation>Onderlijk zoom</translation>
    </message>
</context>
<context>
    <name>CRigSailWidget</name>
    <message>
        <source>Sail information</source>
        <translation type="obsolete">Zeil informatie</translation>
    </message>
    <message>
        <source>file</source>
        <translation type="obsolete">bestand</translation>
    </message>
    <message>
        <source>name</source>
        <translation type="obsolete">naam</translation>
    </message>
    <message>
        <source>Reload</source>
        <translation type="obsolete">Opnieuw laden</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation type="obsolete">Verwijderen</translation>
    </message>
    <message>
        <source>Update</source>
        <translation type="obsolete">Verversen</translation>
    </message>
    <message>
        <source>error</source>
        <translation type="obsolete">fout</translation>
    </message>
    <message>
        <source>There was an error reading from the selected file.</source>
        <translation type="obsolete">Er is een fout opgetreden bij het lezen van het bestand.</translation>
    </message>
</context>
<context>
    <name>CSailDataPrinter</name>
    <message>
        <location filename="../sailprinter.cpp" line="44"/>
        <source>Sailcut CAD data sheet</source>
        <translation>Sailcut CAD data sheet</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="50"/>
        <source>Mainsail</source>
        <translation>Grootzeil</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="53"/>
        <source>Jib</source>
        <translation>Fok</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="56"/>
        <source>Wing</source>
        <translation>Vleugel</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="56"/>
        <source>deg</source>
        <translation>gr</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="59"/>
        <source>Sail type</source>
        <translation>Zeil type</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="65"/>
        <source>Cross Cut</source>
        <translation>Schuin gesneden</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="68"/>
        <source>Horizontal Cut</source>
        <translation>Horizontaal gesneden</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="71"/>
        <source>Radial Cut</source>
        <translation>Radiaal gesneden</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="72"/>
        <source>sections</source>
        <translation> secties </translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="73"/>
        <source>head gores</source>
        <translation> top banen</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="74"/>
        <source>luff gores</source>
        <translation> voorlijk banen</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="77"/>
        <source>Twist Foot Cut</source>
        <translation>Gedraaid Onderlijk</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="80"/>
        <source>Vertical Cut</source>
        <translation>Verticaal gesneden</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="83"/>
        <source>Mitre Cut</source>
        <translation>Verstek gesneden</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="86"/>
        <source>Mitre Cut 2</source>
        <translation>Verstek 2 gesneden</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="89"/>
        <source>Sail layout</source>
        <translation>Zeilontwerp</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="92"/>
        <source>Rig</source>
        <translation>Tuigage</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="93"/>
        <source>Boat LOA</source>
        <translation>Scheepslengte LOA</translation>
    </message>
    <message>
        <source>Mast/Luff rake</source>
        <translation type="obsolete">Mast/Voorlijk helling</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="95"/>
        <source>Tack position X</source>
        <translation>Halshoek positie X</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="96"/>
        <source>Tack height Y</source>
        <translation>Halshoek hoogte Y</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="97"/>
        <source>Fore triangle hoist I</source>
        <translation>Voordriehoek hoogte I</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="98"/>
        <source>Fore triangle base J</source>
        <translation>Voordriehoek basis J</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="101"/>
        <source>Sail dimensions</source>
        <translation>Zeil afmetingen</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="102"/>
        <source>Luff length</source>
        <translation>Voorlijk lengte</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="103"/>
        <source>Foot length</source>
        <translation>Onderlijk lengte</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="104"/>
        <source>Leech length</source>
        <translation>Achterlijk lengte</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="105"/>
        <source>Gaff length</source>
        <translation>Gaffel lengte</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="106"/>
        <source>Gaff angle wrt luff</source>
        <translation>Gaffel-mast hoek</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="109"/>
        <source>Shape of edges</source>
        <translation>Vorm van de randen</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="110"/>
        <source>Luff round</source>
        <translation>Voorlijk ronding</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="111"/>
        <source>Luff round position</source>
        <translation>Voorlijk ronding positie</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="112"/>
        <source>Foot round</source>
        <translation>Onderlijk ronding</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="113"/>
        <source>Foot round position</source>
        <translation>Onderlijk ronding positie</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="114"/>
        <source>Leech round</source>
        <translation>Achterlijk ronding</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="115"/>
        <source>Leech round position</source>
        <translation>Achterlijk ronding positie</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="116"/>
        <source>Gaff round</source>
        <translation>Gaffel ronding</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="117"/>
        <source>Gaff round position</source>
        <translation>Gaffel ronding positie</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="120"/>
        <source>Sail settings</source>
        <translation>Zeil instellingen</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="121"/>
        <source>Twist angle</source>
        <translation>Twist hoek</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="122"/>
        <source>Sheeting angle</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="125"/>
        <source>Cloth seams and hems</source>
        <translation>Doek naden en zomen</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="126"/>
        <source>Cloth width</source>
        <translation>Baan breedte</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="127"/>
        <source>Seams width</source>
        <translation>Naad breedte</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="128"/>
        <source>Leech hem width</source>
        <translation>Achterlijk zoom breedte</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="129"/>
        <source>Foot hem width</source>
        <translation>Onderlijk zoom breedte</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="130"/>
        <source>Other hems width</source>
        <translation>Overige zoom breedte</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="133"/>
        <source>Sail mould</source>
        <translation>Zeilvorm</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="134"/>
        <source>Luff factor</source>
        <translation>Voorlijk factor</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="134"/>
        <source>Depth</source>
        <translation>Diepte</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="134"/>
        <source>Leech factor</source>
        <translation>Achterlijk factor</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="136"/>
        <source>Top profile</source>
        <translation>Top profiel</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="142"/>
        <source>Mid profile at h = </source>
        <translation>Midden profiel bij h = </translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="148"/>
        <source>Bottom profile</source>
        <translation>Onderlijk profiel</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="94"/>
        <source>Luff rake</source>
        <translation>Voorlijk helling</translation>
    </message>
</context>
<context>
    <name>CSailDevelPrinter</name>
    <message>
        <location filename="../sailprinter.cpp" line="190"/>
        <source>Scale</source>
        <translation>Schaal</translation>
    </message>
</context>
<context>
    <name>CSailDispGL</name>
    <message>
        <source>This system has no OpenGL support.</source>
        <translation type="obsolete">Dit systeem ondersteunt geen OpenGL.</translation>
    </message>
</context>
<context>
    <name>CSailDrawingPrinter</name>
    <message>
        <location filename="../sailprinter.cpp" line="221"/>
        <source>Scale</source>
        <translation>Schaal</translation>
    </message>
</context>
<context>
    <name>CSailPrinter</name>
    <message>
        <source>Sailcut CAD data sheet</source>
        <translation type="obsolete">Sailcut CAD data sheet</translation>
    </message>
    <message>
        <source>Mainsail</source>
        <translation type="obsolete">Grootzeil</translation>
    </message>
    <message>
        <source>Jib</source>
        <translation type="obsolete">Fok</translation>
    </message>
    <message>
        <source>Wing</source>
        <translation type="obsolete">Vleugel</translation>
    </message>
    <message>
        <source>deg</source>
        <translation type="obsolete">gr</translation>
    </message>
    <message>
        <source>Sail type</source>
        <translation type="obsolete">Zeil type</translation>
    </message>
    <message>
        <source>Cross Cut</source>
        <translation type="obsolete">Schuin gesneden</translation>
    </message>
    <message>
        <source>Horizontal Cut</source>
        <translation type="obsolete">Horizontaal gesneden</translation>
    </message>
    <message>
        <source>Radial Cut</source>
        <translation type="obsolete">Radiaal gesneden</translation>
    </message>
    <message>
        <source>sections</source>
        <translation type="obsolete"> secties </translation>
    </message>
    <message>
        <source>head gores</source>
        <translation type="obsolete"> top banen</translation>
    </message>
    <message>
        <source>luff gores</source>
        <translation type="obsolete"> voorlijk banen</translation>
    </message>
    <message>
        <source>Twist Foot Cut</source>
        <translation type="obsolete">Gedraaid onderlijk</translation>
    </message>
    <message>
        <source>Vertical Cut</source>
        <translation type="obsolete">Verticaal gesneden</translation>
    </message>
    <message>
        <source>Mitre Cut</source>
        <translation type="obsolete">Verstek gesneden</translation>
    </message>
    <message>
        <source>Sail layout</source>
        <translation type="obsolete">Zeilontwerp</translation>
    </message>
    <message>
        <source>Rig</source>
        <translation type="obsolete">Tuigage</translation>
    </message>
    <message>
        <source>Boat LOA</source>
        <translation type="obsolete">Scheepslengte LOA</translation>
    </message>
    <message>
        <source>Mast/Luff rake</source>
        <translation type="obsolete">Mast/Voorlijk helling</translation>
    </message>
    <message>
        <source>Tack position X</source>
        <translation type="obsolete">Halshoek positie X</translation>
    </message>
    <message>
        <source>Tack height Y</source>
        <translation type="obsolete">Halshoek hoogte Y</translation>
    </message>
    <message>
        <source>Fore triangle hoist I</source>
        <translation type="obsolete">Voordriehoek hoogte I</translation>
    </message>
    <message>
        <source>Fore triangle base J</source>
        <translation type="obsolete">Voordriehoek basis J</translation>
    </message>
    <message>
        <source>Sail dimensions</source>
        <translation type="obsolete">Zeil afmetingen</translation>
    </message>
    <message>
        <source>Luff length</source>
        <translation type="obsolete">Voorlijk lengte</translation>
    </message>
    <message>
        <source>Foot length</source>
        <translation type="obsolete">Onderlijk lengte</translation>
    </message>
    <message>
        <source>Leech length</source>
        <translation type="obsolete">Achterlijk lengte</translation>
    </message>
    <message>
        <source>Gaff length</source>
        <translation type="obsolete">Gaffel lengte</translation>
    </message>
    <message>
        <source>Gaff angle wrt luff</source>
        <translation type="obsolete">Gaffel-mast hoek</translation>
    </message>
    <message>
        <source>Shape of edges</source>
        <translation type="obsolete">Vorm van de randen</translation>
    </message>
    <message>
        <source>Luff round</source>
        <translation type="obsolete">Voorlijk ronding</translation>
    </message>
    <message>
        <source>Luff round position</source>
        <translation type="obsolete">Voorlijk ronding positie</translation>
    </message>
    <message>
        <source>Foot round</source>
        <translation type="obsolete">Onderlijk ronding</translation>
    </message>
    <message>
        <source>Foot round position</source>
        <translation type="obsolete">Onderlijk ronding positie</translation>
    </message>
    <message>
        <source>Leech round</source>
        <translation type="obsolete">Achterlijk ronding</translation>
    </message>
    <message>
        <source>Leech round position</source>
        <translation type="obsolete">Achterlijk ronding positie</translation>
    </message>
    <message>
        <source>Gaff round</source>
        <translation type="obsolete">Gaffel ronding</translation>
    </message>
    <message>
        <source>Gaff round position</source>
        <translation type="obsolete">Gaffel ronding positie</translation>
    </message>
    <message>
        <source>Sail settings</source>
        <translation type="obsolete">Zeil instellingen</translation>
    </message>
    <message>
        <source>Twist angle</source>
        <translation type="obsolete">Twist hoek</translation>
    </message>
    <message>
        <source>Sheeting angle</source>
        <translation type="obsolete">Schoothoek</translation>
    </message>
    <message>
        <source>Cloth seams and hems</source>
        <translation type="obsolete">Doek naden en zomen</translation>
    </message>
    <message>
        <source>Cloth width</source>
        <translation type="obsolete">Baan breedte</translation>
    </message>
    <message>
        <source>Seams width</source>
        <translation type="obsolete">Naad breedte</translation>
    </message>
    <message>
        <source>Leech hem width</source>
        <translation type="obsolete">Achterlijk zoom breedte</translation>
    </message>
    <message>
        <source>Other hem width</source>
        <translation type="obsolete">Overige zoom breedte</translation>
    </message>
    <message>
        <source>Sail mould</source>
        <translation type="obsolete">Zeilvorm</translation>
    </message>
    <message>
        <source>Luff factor</source>
        <translation type="obsolete">Voorlijk factor</translation>
    </message>
    <message>
        <source>Depth</source>
        <translation type="obsolete">Diepte</translation>
    </message>
    <message>
        <source>Leech factor</source>
        <translation type="obsolete">Achterlijk factor</translation>
    </message>
    <message>
        <source>Top profile</source>
        <translation type="obsolete">Top profiel</translation>
    </message>
    <message>
        <source>Mid profile at h = </source>
        <translation type="obsolete">Midden profiel bij h = </translation>
    </message>
    <message>
        <source>Bottom profile</source>
        <translation type="obsolete">Onderlijk profiel</translation>
    </message>
</context>
<context>
    <name>CSailViewerPanel</name>
    <message>
        <location filename="../sailviewer-panel.cpp" line="137"/>
        <source>Display parameters</source>
        <translation>Beeld parameters</translation>
    </message>
    <message>
        <location filename="../sailviewer-panel.cpp" line="138"/>
        <source>elevation</source>
        <translation>hoogtehoek</translation>
    </message>
    <message>
        <location filename="../sailviewer-panel.cpp" line="139"/>
        <source>azimuth</source>
        <translation>azimut</translation>
    </message>
    <message>
        <location filename="../sailviewer-panel.cpp" line="141"/>
        <source>Controls</source>
        <translation>Controleer</translation>
    </message>
    <message>
        <location filename="../sailviewer-panel.cpp" line="142"/>
        <source>Reset view</source>
        <translation>Beeld aanpassen</translation>
    </message>
    <message>
        <location filename="../sailviewer-panel.cpp" line="145"/>
        <source>Labeling</source>
        <translation>Labels</translation>
    </message>
    <message>
        <location filename="../sailviewer-panel.cpp" line="147"/>
        <source>Zoom in</source>
        <translation>Inzoomen</translation>
    </message>
    <message>
        <location filename="../sailviewer-panel.cpp" line="148"/>
        <source>Zoom out</source>
        <translation>Uitzoomen</translation>
    </message>
    <message>
        <location filename="../sailviewer-panel.cpp" line="186"/>
        <source>deg</source>
        <translation>gr</translation>
    </message>
</context>
<context>
    <name>CSailViewerTabs</name>
    <message>
        <location filename="../sailviewer-tabs.cpp" line="60"/>
        <source>shaded view</source>
        <translation>3D model</translation>
    </message>
    <message>
        <location filename="../sailviewer-tabs.cpp" line="62"/>
        <source>wireframe view</source>
        <translation>draadmodel</translation>
    </message>
</context>
<context>
    <name>CWidgetProfile</name>
    <message>
        <location filename="../widgetprofile.cpp" line="243"/>
        <source>Luff shape</source>
        <translation>Voorlijk vorm</translation>
    </message>
    <message>
        <location filename="../widgetprofile.cpp" line="244"/>
        <source>Depth</source>
        <translation>Diepte</translation>
    </message>
    <message>
        <location filename="../widgetprofile.cpp" line="245"/>
        <source>%</source>
        <translation>%</translation>
    </message>
    <message>
        <location filename="../widgetprofile.cpp" line="246"/>
        <source>Leech shape</source>
        <translation>Achterlijk vorm</translation>
    </message>
    <message>
        <location filename="../widgetprofile.cpp" line="250"/>
        <source>degrees</source>
        <translation>grad</translation>
    </message>
    <message>
        <location filename="../widgetprofile.cpp" line="249"/>
        <source>cord</source>
        <translation>Koorde</translation>
    </message>
</context>
<context>
    <name>Dialog</name>
    <message>
        <source>Dialog</source>
        <translation type="obsolete">Dialoog</translation>
    </message>
</context>
<context>
    <name>XmlReaderTempl</name>
    <message>
        <source>error</source>
        <translation type="obsolete">fout</translation>
    </message>
    <message>
        <source>There was an error reading from the selected file.</source>
        <translation type="obsolete">Er is een fout opgetreden bij het lezen van het bestand.</translation>
    </message>
</context>
</TS>
